@@ -1,4 +1,3 @@
-# $Id: Empty.pm,v 1.8 2007/05/15 12:04:20 Daddy Exp $
 
 =head1 NAME
 
@@ -24,18 +23,21 @@ actually being connected to any particular search engine.
 
 =head1 AUTHOR
 
-Martin Thurn <mthurn@cpan.org>
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =cut
 
 package WWW::Search::Null::Empty;
 
 use strict;
+use warnings;
 
 use base 'WWW::Search';
+
 our
-$VERSION = do { my @r = (q$Revision: 1.8 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
-our $MAINTAINER = q{Martin Thurn <mthurn@cpan.org>};
+$VERSION = 1.11;
+our
+$MAINTAINER = q{Martin Thurn <mthurn@cpan.org>};
 
 sub _native_setup_search
   {
@@ -49,6 +51,8 @@ sub _native_retrieve_some
   my $response = new HTTP::Response(200,
                                     "This is a test of WWW::Search");
   $self->{response} = $response;
+  # Explicitly set the number of results:
+  $self->{'approx_count'} = 0;
   return 0;
   } # native_retrieve_some
 
