@@ -1,4 +1,4 @@
-# $Id: NoVersion.pm,v 1.3 2007/05/15 12:04:21 Daddy Exp $
+# $Id: NoVersion.pm,v 1.5 2010-12-02 23:45:57 Martin Exp $
 
 =head1 NAME
 
@@ -17,13 +17,14 @@ This module is for testing the WWW::Search module.
 
 =head1 AUTHOR
 
-Martin Thurn <mthurn@cpan.org>
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =cut
 
 package WWW::Search::Null::NoVersion;
 
 use strict;
+use warnings;
 
 use base 'WWW::Search';
 our $MAINTAINER = q{Martin Thurn <mthurn@cpan.org>};
